==> haskell-hls-change-type-signature-plugin-2.1.0.0-99-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-hls-change-type-signature-plugin.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hls-change-type-signature-plugin
version:              2.1.0.0
visibility:           public
id:
    hls-change-type-signature-plugin-2.1.0.0-95HOrpXham67voePWhHgW4

key:
    hls-change-type-signature-plugin-2.1.0.0-95HOrpXham67voePWhHgW4

license:              Apache-2.0
maintainer:           nicksuchecki@gmail.com
author:               Nick Suchecki
synopsis:             Change a declarations type signature with a Code Action
description:
    Please see the README on GitHub at <https://github.com/haskell/plugins/hls-change-type-signature-plugin/README.md>

category:             Development
abi:                  495965e9123a3fb6d4f36ae9a2ad82f9
exposed:              True
exposed-modules:      Ide.Plugin.ChangeTypeSignature
import-dirs:
    /usr/lib/ghc-9.6.6/site-local/hls-change-type-signature-plugin-2.1.0.0

library-dirs:
    /usr/lib/ghc-9.6.6/site-local/hls-change-type-signature-plugin-2.1.0.0

library-dirs-static:
    /usr/lib/ghc-9.6.6/site-local/hls-change-type-signature-plugin-2.1.0.0

dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hls-change-type-signature-plugin
hs-libraries:
    HShls-change-type-signature-plugin-2.1.0.0-95HOrpXham67voePWhHgW4

depends:
    base-4.18.2.1 containers-0.6.7
    ghcide-2.1.0.0-BlCpiz4ZHvtIqUTiKV6UyX
    hls-plugin-api-2.1.0.0-IyHsVCiLch7D25xEM5t6Zs
    lsp-types-2.0.1.0-KsWoulY9wwoKMSLEqbLHCK
    regex-tdfa-1.3.2.5-ATqtlBuPETHJOcVIKuiav2
    syb-0.7.3-7GPFF4ffw0kLXaCjDkD2wt text-2.0.2 transformers-0.6.1.0
    unordered-containers-0.2.20.1-50qrTxmoJy9AxZ7OdMnycu

haddock-interfaces:
    /usr/share/doc/haskell-hls-change-type-signature-plugin/html/hls-change-type-signature-plugin.haddock

haddock-html:
    /usr/share/doc/haskell-hls-change-type-signature-plugin/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-hls-change-type-signature-plugin-2.1.0.0-100-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-hls-change-type-signature-plugin.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hls-change-type-signature-plugin
version:              2.1.0.0
visibility:           public
id:
    hls-change-type-signature-plugin-2.1.0.0-AToSuI2aahB7OykeufzXD9

key:
    hls-change-type-signature-plugin-2.1.0.0-AToSuI2aahB7OykeufzXD9

license:              Apache-2.0
maintainer:           nicksuchecki@gmail.com
author:               Nick Suchecki
synopsis:             Change a declarations type signature with a Code Action
description:
    Please see the README on GitHub at <https://github.com/haskell/plugins/hls-change-type-signature-plugin/README.md>

category:             Development
abi:                  6449c142c3a71f47f061f2aa041fe7b1
exposed:              True
exposed-modules:      Ide.Plugin.ChangeTypeSignature
import-dirs:
    /usr/lib/ghc-9.6.6/site-local/hls-change-type-signature-plugin-2.1.0.0

library-dirs:
    /usr/lib/ghc-9.6.6/site-local/hls-change-type-signature-plugin-2.1.0.0

library-dirs-static:
    /usr/lib/ghc-9.6.6/site-local/hls-change-type-signature-plugin-2.1.0.0

dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hls-change-type-signature-plugin
hs-libraries:
    HShls-change-type-signature-plugin-2.1.0.0-AToSuI2aahB7OykeufzXD9

depends:
    base-4.18.2.1 containers-0.6.7
    ghcide-2.1.0.0-FnivsoqaY804ocwiGSGs4S
    hls-plugin-api-2.1.0.0-DLt74c0m6zn5iIl3F9hXDn
    lsp-types-2.0.1.0-KsWoulY9wwoKMSLEqbLHCK
    regex-tdfa-1.3.2.5-ATqtlBuPETHJOcVIKuiav2
    syb-0.7.3-7GPFF4ffw0kLXaCjDkD2wt text-2.0.2 transformers-0.6.1.0
    unordered-containers-0.2.20.1-50qrTxmoJy9AxZ7OdMnycu

haddock-interfaces:
    /usr/share/doc/haskell-hls-change-type-signature-plugin/html/hls-change-type-signature-plugin.haddock

haddock-html:
    /usr/share/doc/haskell-hls-change-type-signature-plugin/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
